/* Constructs varialbles of interest from the merged data sets*/

clear
set maxvar 3500, perm
set mem 1g
use 3rd.dta

/*Drop observations with conflicting in home and in school gender reports*/
drop if s2 == 2 & bio_sex == 1 | s2 == 1 & bio_sex == 2


/*Make partner definitions mutually exclusive:*/
gen partrace1 = 0
replace partrace1 = 1 if h1ri18a1 == 1
replace partrace1 = 2 if h1ri18b1 == 1
replace partrace1 = 3 if h1ri16_1 == 1
replace partrace1 = 4 if h1ri18d1 == 1
replace partrace1 = 5 if (h1ri18e1 == 1| h1ri18c1==1 )  & h1ri18d1 != 1 & h1ri16_1 != 1 & h1ri18b1 != 1
la var partrace1 "white=1,black=2, hisp=3,  asian=4, other=0"

gen partrace2 = 0
replace partrace2 = 1 if h1ri18a2 == 1
replace partrace2 = 2 if h1ri18b2 == 1
replace partrace2 = 3 if h1ri16_2 == 1
replace partrace2 = 4 if h1ri18d2 == 1
replace partrace2 = 5 if (h1ri18e2 == 1| h1ri18c2==1 ) & h1ri18d2 != 1 & h1ri16_2 != 1 & h1ri18b2 != 1
la var partrace2 "white=1, black=2,hisp=3, asian=4, other=0"

gen partrace3 = 0
replace partrace3 = 1 if h1ri18a3 == 1
replace partrace3 = 2 if h1ri18b3 == 1
replace partrace3 = 3 if h1ri16_3 == 1
replace partrace3 = 4 if h1ri18d3 == 1
replace partrace3 = 5 if (h1ri18e3 == 1 | h1ri18c1==1 ) & h1ri18d3 != 1 & h1ri16_3 != 1 & h1ri18b3 != 1
la var partrace3 "white=1, black=2, hisp=3, asian=4, other=0"

gen partrace1nr = 0
replace partrace1nr = 1 if h1nr18a1 == 1
replace partrace1nr = 2 if h1nr18b1 == 1
replace partrace1nr = 3 if h1nr16_1 == 1
replace partrace1nr = 4 if h1nr18d1 == 1
replace partrace1nr = 5 if ((h1nr18e1 == 1| h1nr18c1==1 )  & h1nr18d1 != 1 & h1nr16_1 != 1 & h1nr18b1 != 1)
la var partrace1nr "white=1,black=2, hisp=3,  asian=4, other=0"

gen partrace2nr = 0
replace partrace2nr = 1 if  h1nr18a2 == 1
replace partrace2nr = 2 if  h1nr18b2 == 1
replace partrace2nr = 3 if  h1nr16_2 == 1
replace partrace2nr = 4 if  h1nr18d2 == 1
replace partrace2nr = 5 if  ((h1nr18e2 == 1| h1nr18c2==1 ) & h1nr18d2 != 1 & h1nr16_2 != 1 & h1nr18b2 != 1)
la var partrace2nr "white=1, black=2,hisp=3, asian=4, other=0"

gen partrace3nr = 0
replace partrace3nr = 1 if h1nr18a3 == 1
replace partrace3nr = 2 if h1nr18b3 == 1
replace partrace3nr = 3 if h1nr16_3 == 1
replace partrace3nr = 4 if h1nr18d3 == 1
replace partrace3nr = 5 if ((h1nr18e3 == 1 | h1nr18c1==1 ) & h1nr18d3 != 1 & h1nr16_3 != 1 & h1nr18b3 != 1) 
la var partrace3nr "white=1, black=2, hisp=3, asian=4, other=0"

gen partrace1nx = 0
replace partrace1nx = 1 if h1rx18a1 == 1 
replace partrace1nx = 2 if h1rx18b1 == 1 
replace partrace1nx = 3 if h1rx16_1 == 1 
replace partrace1nx = 4 if h1rx18d1 == 1 
replace partrace1nx = 5 if ((h1rx18e1 == 1| h1rx18c1==1 )  & h1rx18d1 != 1 & h1rx16_1 != 1 & h1rx18b1 != 1)
la var partrace1nx "white=1,black=2, hisp=3,  asian=4, other=0"

gen partrace2nx = 0
replace partrace2nx = 1 if h1rx18a2 == 1 
replace partrace2nx = 2 if h1rx18b2 == 1 
replace partrace2nx = 3 if h1rx16_2 == 1 
replace partrace2nx = 4 if h1rx18d2 == 1 
replace partrace2nx = 5 if ((h1rx18e2 == 1| h1rx18c2==1 ) & h1rx18d2 != 1 & h1rx16_2 != 1 & h1rx18b2 != 1) 
la var partrace2nx "white=1, black=2,hisp=3, asian=4, other=0"

gen partrace3nx = 0
replace partrace3nx = 1 if h1rx18a3 == 1 | h1nr18a3 == 1
replace partrace3nx = 2 if h1rx18b3 == 1 | h1nr18b3 == 1
replace partrace3nx = 3 if h1rx16_3 == 1 | h1nr16_3 == 1
replace partrace3nx = 4 if h1rx18d3 == 1 | h1nr18d3 == 1
replace partrace3nx = 5 if ((h1rx18e3 == 1 | h1rx18c1==1 ) & h1rx18d3 != 1 & h1rx16_3 != 1 & h1rx18b3 != 1) 
la var partrace3nx "white=1, black=2, hisp=3, asian=4, other=0"


*********************************************
/*Creating Dates and Sex definitions */
*********************************************
*Interview
gen intyear = 1900 + iyear
gen dateInt  =  mdy(imonth, iday, intyear)
format dateInt %d

*End of Last Relationship
gen relendy1 = 1900 + h1ri11y1 if h1ri11y1 < 96
gen relendm1 = h1ri11m1 if h1ri11m1 < 13
gen dateend1  =  mdy(relendm1, iday, relendy1)

gen relendy2 = 1900 + h1ri11y2 if h1ri11y2 < 96
gen relendm2 = h1ri11m2 if h1ri11m2 < 13
gen dateend2  =  mdy(relendm2, iday, relendy2)

gen relendy3 = 1900 + h1ri11y3 if h1ri11y3 < 96
gen relendm3 = h1ri11m3 if h1ri11m3 < 13
gen dateend3  =  mdy(relendm3, iday, relendy3)

gen relendy1nx = 1900 + h1rx11y1 if h1rx11y1 < 96
gen relendm1nx = h1rx11m1 if h1rx11m1 < 13
gen dateend1nx  =  mdy(relendm1nx, iday, relendy1nx)
gen relendy2nx = 1900 + h1rx11y2 if h1rx11y2 < 96
gen relendm2nx = h1rx11m2 if h1rx11m2 < 13
gen dateend2nx  =  mdy(relendm2nx, iday, relendy2nx)
gen relendy3nx = 1900 + h1rx11y3 if h1rx11y3 < 96
gen relendm3nx = h1rx11m3 if h1rx11m3 < 13
gen dateend3nx  =  mdy(relendm3nx, iday, relendy3nx)


gen maxdate = dateend1 if dateend2 == . & dateend3 == .
replace maxdate = dateend2 if dateend1 == . & dateend3 == .
replace maxdate = dateend3 if dateend1 == . & dateend2 == .
replace maxdate = max(dateend1,dateend2) if dateend3 == . & dateend2 != . & dateend1 != .
replace maxdate = max(dateend1,dateend3) if dateend3 != . & dateend2 == . & dateend1 != .
replace maxdate = max(dateend2,dateend3) if dateend3 != . & dateend2 != . & dateend1 == .
replace maxdate = max(dateend1,dateend2,dateend3) if dateend3 != . & dateend2 != . & dateend1 != .

gen maxdatenx = dateend1nx if dateend2nx == . & dateend3nx == .
replace maxdatenx = dateend2nx if dateend1nx == . & dateend3nx == .
replace maxdatenx = dateend3nx if dateend1nx == . & dateend2nx == .
replace maxdatenx = max(dateend1nx,dateend2nx) if dateend3nx == . & dateend2nx != . & dateend1nx != .
replace maxdatenx = max(dateend1nx,dateend3nx) if dateend3nx != . & dateend2nx == . & dateend1nx != .
replace maxdatenx = max(dateend2nx,dateend3nx) if dateend3nx != . & dateend2nx != . & dateend1nx == .
replace maxdatenx = max(dateend1nx,dateend2nx,dateend3nx) if dateend3nx != . & dateend2nx != . & dateend1nx != .

gen mostrecrel = 1 if (maxdate == dateend1 & maxdate != . ) & (h1ri21j1 == 1 &  h1ri21m1 == 1 &  h1ri21f1 == 1)
replace mostrecrel = 2 if (maxdate == dateend2 & maxdate != . ) & (h1ri21j2 == 1 &  h1ri21m2 == 1 &  h1ri21f2 == 1)
replace mostrecrel = 3 if (maxdate == dateend3 & maxdate != . ) & (h1ri21j3 == 1 &  h1ri21m3 == 1 &  h1ri21f3 == 1)

gen mostrecrelnx = 1 if (maxdatenx == dateend1nx & maxdatenx != . ) & (h1rx21j1 == 1 &  h1rx21m1 == 1 &  h1rx21f1 == 1)
replace mostrecrelnx = 2 if (maxdatenx == dateend2nx & maxdatenx != . ) & (h1rx21j2 == 1 &  h1rx21m2 == 1 &  h1rx21f2 == 1)
replace mostrecrelnx = 3 if (maxdatenx == dateend3nx & maxdatenx != . ) & (h1rx21j3 == 1 &  h1rx21m3 == 1 &  h1rx21f3 == 1)

gen tsincemostrec = dateInt - maxdate
gen relmonth = month(tsincemostrec)
gen relyear = year(tsincemostrec) - 1960
gen monthssincerel = relyear*12 + relmonth if maxdate < . & mostrecrel>0
*replace monthssincerel = 0 if  h1ri10_1  == 1 | (h1ri10_2  == 1 & h1ri10_1  == 0 & h1ri10_3  == 0) | (h1ri10_3  == 1 & h1ri10_1  == 0 & h1ri10_2  == 0)

gen tsincemostrecnx = dateInt - maxdatenx
gen relmonthnx = month(tsincemostrecnx)
gen relyearnx = year(tsincemostrecnx) - 1960
gen monthssincerelnx = relyear*12 + relmonthnx if maxdatenx < . & mostrecrelnx>0

*replace monthssincerelnx = 0 if  h1ri10_1  == 1 | (h1ri10_2  == 1 & h1ri10_1  == 0 & h1ri10_3  == 0) | (h1ri10_3  == 1 & h1ri10_1  == 0 & h1ri10_2  == 0)

*1st Sex
gen year1stsex = .
replace year1stsex = 1900 + h1co2y if h1co2y < 96 
gen sexday = 1 if year1stsex ~= .
gen mo1stsex = .
replace mo1stsex = h1co2m if h1co2m < 96 
gen date1stsex =   mdy(mo1stsex, sexday, year1stsex) 
format date1stsex %d

*Most Recent Sex
gen yearrecsex = .
replace yearrecsex = 1900 + h1co5y if h1co5y < 96 
gen sexdayrec = 1 if year1stsex ~= .
gen morecsex = .
replace morecsex = h1co5m if h1co5m < 96 
gen daterecsex =  mdy(morecsex, sexdayrec, yearrecsex) 
format daterecsex %d

gen timesincesex = dateInt - daterecsex
gen sexmonth = month(timesincesex)
gen sexyear = year(timesincesex) - 1960
gen monthssincesex = sexyear*12 + sexmonth

**********************************************************
*Most Recent NR Sex
**********************************************************
*Setting date within month
gen sexdayrecnr = 1 

*Rel 1, Non-Romantic
*********************
gen yearrecsexnr1 = .
replace yearrecsexnr1 = 1900 + h1nr24y1 if h1nr24y1 < 96 
gen morecsexnr1 = .
replace morecsexnr1 = h1nr24m1 if h1nr24m1 < 96 
gen datesexnr1 =  mdy(morecsexnr1, sexdayrecnr, yearrecsexnr1) 
drop yearrecsexnr1 morecsexnr1

*Rel 1, recategorized as Romantic
*********************************
gen yearrecsexnr1 = .
replace yearrecsexnr1 = 1900 + h1rx26y1 if h1rx26y1 < 96 
gen morecsexnr1 = .
replace morecsexnr1 = h1rx26m1 if h1rx26m1 < 96 
replace datesexnr1 = mdy(morecsexnr1, sexdayrecnr, yearrecsexnr1) if (h1rx26y1 < 96 & h1rx26m1 < 96) 
format datesexnr1 %d

*Rel 2, Non-Romantic
*********************
gen yearrecsexnr2 = .
replace yearrecsexnr2 = 1900 + h1nr24y2 if h1nr24y2 < 96 
gen morecsexnr2 = .
replace morecsexnr2 = h1nr24m2 if h1nr24m2 < 96 
gen datesexnr2 =  mdy(morecsexnr2, sexdayrecnr, yearrecsexnr2) 
drop yearrecsexnr2 morecsexnr2

*Rel 2, recategorized as Romantic
*********************************
gen yearrecsexnr2 = .
replace yearrecsexnr2 = 1900 + h1rx26y2 if h1rx26y2 < 96 
gen morecsexnr2 = .
replace morecsexnr2 = h1rx26m2 if h1rx26m2 < 96 
replace datesexnr2 = mdy(morecsexnr2, sexdayrecnr, yearrecsexnr2) if (h1rx26y2 < 96 & h1rx26m2 < 96) 
format datesexnr2 %d

*Rel 3, Non-Romantic
*********************
gen yearrecsexnr3 = .
replace yearrecsexnr3 = 1900 + h1nr24y3 if h1nr24y3 < 96 
gen morecsexnr3 = .
replace morecsexnr3 = h1nr24m3 if h1nr24m3 < 96 
gen datesexnr3 =  mdy(morecsexnr3, sexdayrecnr, yearrecsexnr3) 
drop yearrecsexnr3 morecsexnr3

*Rel 3, recategorized as Romantic
*********************************
gen yearrecsexnr3 = .
replace yearrecsexnr3 = 1900 + h1rx26y3 if h1rx26y3 < 96 
gen morecsexnr3 = .
replace morecsexnr3 = h1rx26m3 if h1rx26m3 < 96 
replace datesexnr3 = mdy(morecsexnr3, sexdayrecnr, yearrecsexnr3) if (h1rx26y3 < 96 & h1rx26m3 < 96) 
format datesexnr3 %d

gen maxdatesexnx = datesexnr1 if datesexnr2 == . & datesexnr3 == .
replace maxdatesexnx = datesexnr2 if datesexnr1 == . & datesexnr3 == .
replace maxdatesexnx = datesexnr3 if datesexnr1 == . & datesexnr2 == .
replace maxdatesexnx = max(datesexnr1,datesexnr2) if datesexnr3 == . & datesexnr2 != . & datesexnr1 != .
replace maxdatesexnx = max(datesexnr1,datesexnr3) if datesexnr3 != . & datesexnr2 == . & datesexnr1 != .
replace maxdatesexnx = max(datesexnr2,datesexnr3) if datesexnr3 != . & datesexnr2 != . & datesexnr1 == .
replace maxdatesexnx = max(datesexnr1,datesexnr2,datesexnr3) if dateend3nx != . & dateend2nx != . & dateend1nx != .

gen mostrecsexnx = 1 if (maxdatesexnx == datesexnr1 & maxdatesexnx != . )  
replace mostrecsexnx = 2 if (maxdatesexnx == datesexnr2 & maxdatesexnx != . )  
replace mostrecsexnx = 3 if (maxdatesexnx == datesexnr3 & maxdatesexnx != . )  

gen timesincesexnr = dateInt - mostrecsexnx
gen sexmonthnr = month(timesincesexnr)
gen sexyearnr = year(timesincesexnr) - 1960
gen monthssincesexnr = sexyearnr*12 + sexmonthnr

************************************************************
*Defining Had non romantic sex, uses either Current status,
*or if no current status is available uses last month
*************************************************************
gen hadsexlast1nx = 0 if monthssincesexnr < .
replace hadsexlast1nx = 1 if monthssincesexnr > -1 & monthssincesexnr < 2
gen hadsexlast2nx = 0 if monthssincesexnr < .
replace hadsexlast2nx = 1 if  monthssincesexnr < 3
gen hadsexlast3nx = 0 if monthssincesexnr < .
replace hadsexlast3nx = 1 if  monthssincesexnr < 4
gen hadsexlast6nx = 0 if monthssincesexnr < .
replace hadsexlast6nx = 1 if monthssincesexnr < 7
gen hadsexlast18nx = 0 if monthssincesexnr < .
replace hadsexlast18nx = 1 if monthssincesexnr < 19

gen hadrellast1 = 0 
replace hadrellast1 = 1 if monthssincerel > -1  & monthssincerel < 2 
gen hadrellast2 = 0 
replace hadrellast2 = 1 if  monthssincerel < 3
gen hadrellast3 = 0 
replace hadrellast3 = 1 if monthssincerel < 4  
gen hadrellast6 = 0
replace hadrellast6 = 1 if monthssincerel < 7
gen hadrellast12 = 0
replace hadrellast12 = 1 if monthssincerel < 13
gen hadrellast18 = 0
replace hadrellast18 = 1 if monthssincerel < 19 
gen hadrellast24 = 0
replace hadrellast24 = 1 if monthssincerel < 25 

gen hadrellast1nx = 0 
replace hadrellast1nx = 1 if monthssincerelnx > -1  & monthssincerelnx < 2 
gen hadrellast2nx = 0 
replace hadrellast2 = 1 if  monthssincerelnx < 3
gen hadrellast3nx = 0 
replace hadrellast3nx = 1 if monthssincerelnx < 4  
gen hadrellast6nx = 0
replace hadrellast6nx = 1 if monthssincerelnx < 7

gen hadsexlast1 = 0 
replace hadsexlast1 = 1 if monthssincesex > -1  & monthssincesex < 2 
gen hadsexlast2 = 0 
replace hadsexlast2 = 1 if  monthssincesex < 3
gen hadsexlast3 = 0 
replace hadsexlast3 = 1 if  monthssincesex < 4  
gen hadsexlast6 = 0
replace hadsexlast6 = 1 if monthssincesex < 7
gen hadsexlast12 = 0
replace hadsexlast12 = 1 if monthssincesex < 13
gen hadsexlast18 = 0
replace hadsexlast18 = 1 if monthssincesex < 19 
gen hadsexlast24 = 0
replace hadsexlast24 = 1 if monthssincesex < 25 

gen hadrellast18I = 0
replace hadrellast18I = 1 if h1rr1 == 1 | (h1lr1 ==1 & h1lr2 == 1 & h1lr3== 1 & h1lr4 ==1)

gen hadsex = 0 
replace hadsex = 1 if h1co1 == 1

gen hadsexnr = 0 
replace hadsexnr = 1 if h1nr5 == 1

gen day = 1
gen byear = h1gi1y + 1900
gen bday = mdy(h1gi1m, day, byear) if h1gi1m < 96 & h1gi1y < 96
format bday %d

/*Generate WHITE-NON HISPANIC, BLACK, ASIAN*/
replace white = 1 if h1gi6a == 1
replace black = 0 if  h1gi6a == 1
replace hisp = 0 if  h1gi6a == 1
replace asian = 0 if h1gi6a == 1
replace other = 0 if h1gi6a == 1

replace hisp = 1 if  h1gi4 == 1
replace white = 0 if  h1gi4 == 1
replace asian = 0 if  h1gi4 == 1
replace black = 0 if  h1gi4 == 1
replace other = 0 if  h1gi4 == 1

replace black = 1 if h1gi6b == 1
replace white = 0 if h1gi6b == 1 
replace hisp = 0 if h1gi6b == 1
replace other = 0 if h1gi6b == 1
replace asian = 0 if h1gi6b == 1

replace asian = 1 if h1gi6d == 1
replace white = 0 if  h1gi6d == 1 
replace hisp = 0 if h1gi6d == 1
replace other = 0 if h1gi6d == 1
replace black = 0 if h1gi6d == 1

replace other = 1 if white == . | black == . | hisp == . | asian == . 
replace white = 0 if white == . | black == . | hisp == . | asian == . 
replace black = 0 if white == . | black == . | hisp == . | asian == . 
replace hisp = 0 if white == . | black == . | hisp == . | asian == . 
replace asian = 0 if white == . | black == . | hisp == . | asian == . 

gen race = 1 if white == 1 
replace race = 2 if black == 1
replace race = 3 if hisp == 1 
replace race = 4 if asian == 1
replace race = 5 if other == 1

gen grade = 9 if h1gi20 == 9 | (h1gi20 > 14 & s3 == 9)
replace grade = 10 if h1gi20 == 10 | (h1gi20 > 14 & s3 == 10)
replace grade = 11 if h1gi20 == 11 | (h1gi20 > 14 & s3 == 11)
replace grade = 12 if h1gi20 == 12 | (h1gi20 > 14 & s3 == 12)
replace grade = 7 if h1gi20 == 7 | (h1gi20 > 14 & s3 == 7)
replace grade = 8 if h1gi20 == 8 | (h1gi20 > 14 & s3 == 8)
replace grade = 13 if h1gi20 == 13 | (h1gi20 > 14 & s3 == 13)
replace grade = 14 if h1gi20 == 14 | (h1gi20 > 14 & s3 == 14)

gen grade9 = 0
replace grade9 = 1 if grade == 9
gen grade10 = 0
replace grade10 = 1 if grade == 10
gen grade11 = 0
replace grade11 = 1 if grade == 11
gen grade12 = 0
replace grade12 = 1 if grade == 12

gen HSgrade = .
replace HSgrade = grade if grade < 13 & grade > 8

replace boys = 1 if bio_sex == 1
replace boys = 0 if bio_sex == 2
replace girls = 1 if bio_sex == 2
replace girls = 0 if bio_sex == 1

gen minboy = 0
replace minboy = 1 if (grade == 9 & boys ==1 & SchType == 1) | (grade == 10 & boys == 1 & SchType == 2)

gen maxgirl = 0 
replace maxgirl = 1 if grade == 12 & girls == 1 


gen intercat = girls*catholic
gen interpub = girls*public
gen interHSgrade = girls*HSgrade
gen interrace = girls*race
gen interurban = girls*urban
gen interschtype = girls*SchType


save  4th.dta , replace
