function grdd = num_hess(fcn,x0,grdh,nm,numind,t,M_sex_reshape,M_nosex_reshape,W_sex_reshape,W_nosex_reshape,LAG_S,type,grade,boy,sid,RS,SG,SR,PG,PB,PH,PO,G1,G3,R1,R2,YY,NY,SR_b,pctbl,norm,c,Pmatch,G,cens_mat_g,cens_mat_r,cens_mat_none,race,frac_f,frac_m,Pmatchf,Pmatchm)


% Computing numerical hessian using a central difference
%                    
% Inputs:
%
%       fcn = a string naming the objective function.
%        x0 = a column vector n*1, at which point the hessian is evaluated.
%      grdh = step size, use 0 if you want the recomended step size by Dennis and Schnabel
%
% Ouput:
%
%      grdd = hessian matrix (second derivative), n*n.


x0 = x0(:);
size(x0)
%f0 = eval([fcn '(x0)']);
 
f0 = fcn(x0,nm,numind,t,M_sex_reshape,M_nosex_reshape,W_sex_reshape,W_nosex_reshape,LAG_S,type,grade,boy,sid,RS,SG,SR,PG,PB,PH,PO,G1,G3,R1,R2,YY,NY,SR_b,pctbl,norm,c,Pmatch,G,cens_mat_g,cens_mat_r,cens_mat_none,race,frac_f,frac_m,Pmatchf,Pmatchm);
% initializations

k = length(x0);
grdd = zeros(k);

% Computation of stepsize (dh)

if all(grdh)
    dh = grdh;
else
    ax0 = abs(x0);
    if all(x0)
        dax0 = x0 ./ ax0;
    else
        dax0 = 1;
    end
    stps = eps^(1/3);
    % eps: floating point relative accuracy or machine precision: 2.22e-16
    % stps: step size recommended by Dennis and Schnabel: 6.006e-6
    dh = stps * (max([ax0 (1e-2)*ones(k,1)]'))' .* dax0;
end

xdh = x0 + dh;
dh = xdh - x0;    % This increases precision slightly
dhm = dh(:,ones(k,1));
ee = eye(k) .* dhm;

i = 1;
while i <= k
    j = i;
    while j <= k
%        fune1 = eval([fcn '(x0 + ee(:,i) + ee(:,j))']);
        
		fune1 = fcn((x0 + ee(:,i) + ee(:,j)),nm,numind,t,M_sex_reshape,M_nosex_reshape,W_sex_reshape,W_nosex_reshape,LAG_S,type,grade,boy,sid,RS,SG,SR,PG,PB,PH,PO,G1,G3,R1,R2,YY,NY,SR_b,pctbl,norm,c,Pmatch,G,cens_mat_g,cens_mat_r,cens_mat_none,race,frac_f,frac_m,Pmatchf,Pmatchm)%        fune2 = eval([fcn '(x0 - ee(:,i) + ee(:,j))']);
     
		fune2 = fcn((x0 - ee(:,i) + ee(:,j)),nm,numind,t,M_sex_reshape,M_nosex_reshape,W_sex_reshape,W_nosex_reshape,LAG_S,type,grade,boy,sid,RS,SG,SR,PG,PB,PH,PO,G1,G3,R1,R2,YY,NY,SR_b,pctbl,norm,c,Pmatch,G,cens_mat_g,cens_mat_r,cens_mat_none,race,frac_f,frac_m,Pmatchf,Pmatchm); 
%        fune3 = eval([fcn '(x0 + ee(:,i) - ee(:,j))']);
        fune3 = fcn((x0 + ee(:,i) - ee(:,j)),nm,numind,t,M_sex_reshape,M_nosex_reshape,W_sex_reshape,W_nosex_reshape,LAG_S,type,grade,boy,sid,RS,SG,SR,PG,PB,PH,PO,G1,G3,R1,R2,YY,NY,SR_b,pctbl,norm,c,Pmatch,G,cens_mat_g,cens_mat_r,cens_mat_none,race,frac_f,frac_m,Pmatchf,Pmatchm);  
%        fune4 = eval([fcn '(x0 - ee(:,i) - ee(:,j))']);
        fune4 = fcn((x0 - ee(:,i) - ee(:,j)),nm,numind,t,M_sex_reshape,M_nosex_reshape,W_sex_reshape,W_nosex_reshape,LAG_S,type,grade,boy,sid,RS,SG,SR,PG,PB,PH,PO,G1,G3,R1,R2,YY,NY,SR_b,pctbl,norm,c,Pmatch,G,cens_mat_g,cens_mat_r,cens_mat_none,race,frac_f,frac_m,Pmatchf,Pmatchm); 
        grdd(i,j) = (fune1 - fune2 - fune3 + fune4)  / (4 * dh(i) * dh(j));
        if i ~= j
            grdd(j,i) = grdd(i,j);
        end
    j = j+1;
    end
    i = i+1;
end

